@@ -2,7 +2,7 @@
 """Microapp package"""
 
 from .utils import funcargs, funcargseval, appdict
-from .framework import load_appclass
+from .framework import load_appclass, register_appclass, unregister_appclass
 from .manage import Manager
 from .project import Project, MicroappProject
 from .group import (Group, GroupCmd, DepartureNode, ArrivalNode,
