@@ -196,7 +196,7 @@ class App(MicroappObject, AppArgParser, DataRegistry):
         fwds = self._fwds
         self._fwds = appdict()
 
-        self.logger.debug("App '%s' finished." % self._name_)
+        self.logger.debug("App '%s' ran." % self._name_)
 
         return ret, fwds
 
@@ -228,7 +228,7 @@ class App(MicroappObject, AppArgParser, DataRegistry):
 
         return appobj.run(args, None, forward)
 
-    def run_subgroup(self, group_opts=None, group_class=None, app_args=None, forward=None):
+    def run_subgroup(self, group_args=None, group_class=None, app_args=None, forward=None):
 
         if not group_class:
             from microapp.group import GroupCmd
@@ -237,5 +237,5 @@ class App(MicroappObject, AppArgParser, DataRegistry):
 
         grp = group_class(self.get_manager())
 
-        return grp.run(group_opts, app_args, forward)
+        return grp.run(group_args, app_args, forward)
 
