@@ -4,6 +4,7 @@
 from __future__ import print_function
 
 import sys, os, shlex, multiprocessing, json, logging
+from subprocess import Popen, PIPE
 
 from microapp.base import MicroappObject, microapp_builtins
 from microapp.error import (UsageError, InternalError, TypeCheckError,
@@ -42,6 +43,9 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
         obj.add_argument("--share", metavar="expr", action="append",
                 delay=True, help="share variables between sibling apps")
 
+        obj.add_argument("--shell", metavar="cmd", action="append",
+                delay=True, help="execute a shell command")
+
         obj.add_argument("--downcast", metavar="expr", action="append",
                 delay=True, help="downcast variables under this app")
 
@@ -150,7 +154,11 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
             return True
 
         else:
-            return self.get_config(keylist[1:], curcfg=curcfg[key])
+            try:
+                return self.get_config(keylist[1:], curcfg=curcfg[key])
+
+            except ConfigError as err:
+                return False
 
     def get_config(self, keylist, curcfg=None):
 
@@ -226,7 +234,7 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
                     file=sys.stderr)
             sys.exit(1)
 
-        self.logger.debug("Project '%s' is started." % self._name_)
+        self.logger.debug("Project '%s' runs command." % self._name_)
 
         try:
             ret = -1, None
@@ -246,6 +254,26 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
 
             pargs, rargs = self.parse_known_args(pargs, self._env)
 
+            if pargs.shell:
+                cmds = []
+
+                for cmd in pargs.shell:
+                    cmds.append(cmd.data.encode() + b"\n")
+
+                shell = Popen(["sh"], stdin=PIPE, stdout=PIPE)
+                shell.stdin.write(b"\n".join(cmds))
+                shell.stdin.write(b"env\n")
+                shell.stdin.close()
+
+                for line in shell.stdout:
+                    line = tostr(line.strip())
+
+                    try:
+                        name, value = line.split("=", 1)
+                        os.environ[name] = value
+                    except Exception as err:
+                        pass
+
             if pargs.logging:
                 items = [l.strip() for l in pargs.logging["_"].split(",", 1)]
 
@@ -344,7 +372,7 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
             with open(self._cfgfile, "w") as f:
                 json.dump(self._config, f, indent=4, sort_keys=True)
 
-        self.logger.debug("Project '%s' is finished." % self._name_)
+        self.logger.debug("Project '%s' ran." % self._name_)
 
         return ret
 
@@ -372,7 +400,7 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
         else:
             app_args = []
 
-        self.logger.debug("Project '%s' is started." % self._name_)
+        self.logger.debug("Project '%s' runs a class." % self._name_)
 
         try:
             ret = -1, None
@@ -452,7 +480,7 @@ class Project(MicroappObject, ProjectArgParser, Manager, DataRegistry):
             with open(self._cfgfile, "w") as f:
                 json.dump(self._config, f, indent=4, sort_keys=True)
 
-        self.logger.debug("Project '%s' is started." % self._name_)
+        self.logger.debug("Project '%s' ran." % self._name_)
 
         return ret
 
@@ -476,7 +504,7 @@ class MicroappProject(Project):
     """Microapp default project"""
 
     _name_ = "microapp"
-    _version_ = "0.3.7"
+    _version_ = "0.3.8"
     _description_ = "A command-line portal to Microapp apps."
     _long_description_ = "A command-line portal to Microapp apps."
     _author_ = "Youngsung Kim"
